clear all

set seed 13579

forvalues i = 1/40 {

	clear 

	set obs 10000
	gen id = _n
	
	* Generierung der DGP-Komponenten (APK-Effekte, Level 1-Residuen)

	gen B0 = 3.5
	
	gen a1 = -0.21
	gen a2 = 0.05
	gen a3 = 0
	gen a4 = 0.15
	gen a5 = 0.19 
	gen a6 = 0.3
	gen a7 = 0.49

	gen p1 = rnormal(0, 0.1)
	gen p2 = rnormal(-.4, 0.1)
	gen p3 = rnormal(-.41, 0.1)
	gen p4 = rnormal(-.49, 0.1)
	gen p5 = rnormal(-.47, 0.1)
	gen p6 = rnormal(-.57, 0.1)
	gen p7 = rnormal(-.72, 0.1)
	gen p8 = rnormal(-.81, 0.1)
	gen p9 = rnormal(-.90, 0.1)

	gen c1 = rnormal(0, 0.1)
	gen c2 = rnormal(.03, 0.1)
	gen c3 = rnormal(-.1, 0.1)
	gen c4 = rnormal(-.2, 0.1)
	gen c5 = rnormal(-.3, 0.1)
	gen c6 = rnormal(-.35, 0.1)
	gen c7 = rnormal(-.55, 0.1)
	gen c8 = rnormal(-.70, 0.1)
	gen c9 = rnormal(-.8, 0.1)
	gen c10 = rnormal(-.9, 0.1)
	gen c11 = rnormal(-1.0, 0.1)
	gen c12 = rnormal(-1.1, 0.1)
	gen c13 = rnormal(-1.0, 0.1)
	gen c14 = rnormal(-.95, 0.1)
	gen c15 = rnormal(-1.0, 0.1)
	gen c16 = rnormal(-.9, 0.1)
	gen c17 = rnormal(-.97, 0.1)
	gen c18 = rnormal(-.91, 0.1)
	gen c19 = rnormal(-.95, 0.1)

	generate period = floor((9-1+1)*runiform() + 1)
	recode period (1=1982) (2=1991) (3=1992) (4=1996) (5=2000) (6=2004) (7=2008) (8=2012) (9=2016), gen(period2)

	generate age = int(63*uniform())+18
	
	recode age (18/28=1) (29/38=2) (39/48=3) (49/58=4) (59/68=5) (69/78=6) (79/99=7), gen(age_kat)
	tab age_kat, gen(ag)

	generate birthyr = period2-age

	gen per1 = 0
	replace per1 = 1 if period2 == 1982
	gen per2 = 0
	replace per2 = 1 if period2 == 1991
	gen per3 = 0
	replace per3 = 1 if period2 == 1992
	gen per4 = 0
	replace per4 = 1 if period2 == 1996
	gen per5 = 0
	replace per5 = 1 if period2 == 2000
	gen per6 = 0
	replace per6 = 1 if period2 == 2004
	gen per7 = 0
	replace per7 = 1 if period2 == 2008
	gen per8 = 0
	replace per8 = 1 if period2 == 2012
	gen per9 = 0
	replace per9 = 1 if period2 == 2016

	gen coh5y = .
	replace coh5y =  1 if birthyr < 1906
	replace coh5y =  2 if birthyr >= 1906 & birthyr < 1911
	replace coh5y =  3 if birthyr >= 1911 & birthyr < 1916
	replace coh5y =  4 if birthyr >= 1916 & birthyr < 1921
	replace coh5y =  5 if birthyr >= 1921 & birthyr < 1926
	replace coh5y =  6 if birthyr >= 1926 & birthyr < 1931
	replace coh5y =  7 if birthyr >= 1931 & birthyr < 1936
	replace coh5y =  8 if birthyr >= 1936 & birthyr < 1941
	replace coh5y =  9 if birthyr >= 1941 & birthyr < 1946
	replace coh5y = 10 if birthyr >= 1946 & birthyr < 1951
	replace coh5y = 11 if birthyr >= 1951 & birthyr < 1956
	replace coh5y = 12 if birthyr >= 1956 & birthyr < 1961
	replace coh5y = 13 if birthyr >= 1961 & birthyr < 1966
	replace coh5y = 14 if birthyr >= 1966 & birthyr < 1971
	replace coh5y = 15 if birthyr >= 1971 & birthyr < 1976
	replace coh5y = 16 if birthyr >= 1976 & birthyr < 1981
	replace coh5y = 17 if birthyr >= 1981 & birthyr < 1986
	replace coh5y = 18 if birthyr >= 1986 & birthyr < 1991
	replace coh5y = 19 if birthyr >= 1991 & birthyr < 1999

	gen resid = rnormal(0,0.55)
	
	tab coh5y, gen(knr)
    
	* Generierung der abhängigen Variablen (DGP) 
	
	gen y = B0 + (a1*ag1) + (a2*ag2) + (a3*ag3) + (a4*ag4) + (a5*ag5) + (a6* ag6) + (a7*ag7) + (knr1*c1) + (knr2*c2) + (knr3*c3) + (knr4*c4) + (knr5*c5) + (knr6*c6) ///
	+ (knr7*c7) + (knr8*c8) + (knr9*c9) + (knr10*c10) 	+ (knr11*c11) + (knr12*c12) + (knr13*c13) + (knr14*c14) + (knr15*c15) + (knr16*c16) + (knr17*c17) + (knr18*c18) ///
	+ (knr19*c19) + (per1*p1) + (per2*p2) + (per3*p3) + (per4*p4) + (per5*p5) + (per6*p6) + (per7*p7) + (per8*p8) + (per9*p9) + resid
	
	recode y (-1/1=1) (4/6=4)
	
	* Alterszentrierung 
		
	egen age_m1 = mean(age)
	gen age_c = age - age_m1
	
	egen age_m2 = mean(age), by(coh5y)
	gen age_gc = age - age_m2
	
	gen agemq = age_m2*age_m2
	
	* Berechnung der Modelle
	
    bayes, showreffects saving("d:\Simulation\bac`i'", replace): mixed y age_c || _all: R.period || coh5y:

	bayes, showreffects saving("d:\Simulation\bagc`i'", replace): mixed y age_gc || _all: R.period || coh5y:
	
	bayes, showreffects saving("d:\Simulation\bafc`i'", replace): mixed y age_m2 agemq  age || _all: R.period || coh5y:
	
	* Speichern der simulierten Daten 
	
	save "d:\Simulation\simdat`i'", replace
	
	}
	
	






